Learn R Programming

ECSFargateProvider (version 1.0.0)

reconnectDockerCluster,ECSFargateProvider-method: Reconnect the cluster

Description

Reconnect the cluster. This function will check the instances in the ECS cluster defined by provider$clusterName and find if there is any instance that has the same job queue name as .getJobQueueName(cluster). If so, the function can reconnect the cluster.

Usage

# S4 method for ECSFargateProvider
reconnectDockerCluster(provider, cluster, verbose = 0L)

Arguments

provider

S4 CloudProvider object. The service provider.

cluster

S4 DockerCluster object.

verbose

Integer. The verbose level, default 1.

Value

No return value